@@ -285,7 +285,7 @@ class CBuilder(QtWidgets.QMainWindow):
         about = menubar.addAction("About")
         about.triggered.connect(self.about)
 
-
+        self.toolbar_actions = self.addToolBar("Actions")
         self.statusBar()
 
     def about(self):
@@ -539,7 +539,12 @@ GitHub Page: \n\
     def form_wstackedwidget(self, obj):
         """From stackwidget."""
         self.wbaseobj.set_object(obj)
-        self.wdockarea.set_object(obj)
+        w_actions = self.wdockarea.set_object(obj)
+
+        self.toolbar_actions.clear()
+        for w_action in w_actions:
+            self.toolbar_actions.addWidget(w_action)
+
         if self.wdockarea.count() == 0:
             self.wstackedwidget.setCurrentIndex(0)
         else:
