@@ -1,5 +1,5 @@
 """WFunction class."""
-from PyQt5 import QtCore
+from PyQt5 import QtCore, QtWidgets
 import pyqtgraph.dockarea as pg_da
 
 from cryspy_editor.widgets.w_presentation import w_for_presentation
@@ -26,12 +26,16 @@ class WDockArea(pg_da.DockArea):
         self.thread = thread
 
     def normal_clear(self):
+        """Clear procedure has a bug."""
         self.clear()
         if self.count() != 0:
             self.normal_clear()
 
     def set_object(self, obj):
-        """Set text."""
+        """Set text.
+
+        Output is actions
+        """
         if obj is None:
             return
         self.normal_clear()
@@ -41,8 +45,7 @@ class WDockArea(pg_da.DockArea):
         #     self.clear()
 
         docks = []
-        docks = w_for_presentation(obj, self.thread)
-
+        docks, w_actions = w_for_presentation(obj, self.thread)
         l_ordered_docks = []
         i_actions = 0
         for i_dock, dock in enumerate(docks):
@@ -73,3 +76,4 @@ class WDockArea(pg_da.DockArea):
             else:
                 dock.setStretch(x=1, y=1)
                 self.addDock(dock, "right", l_ordered_docks[i_dock-1])
+        return w_actions
